package kr.co.vividnext.sodalive.audition.detail

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import coil.load
import coil.transform.RoundedCornersTransformation
import kr.co.vividnext.sodalive.R
import kr.co.vividnext.sodalive.databinding.ItemAuditionRoleBinding
import kr.co.vividnext.sodalive.extensions.dpToPx

class AuditionDetailRoleAdapter(
    private val onItemClick: (Long) -> Unit
) : ListAdapter<GetAuditionRoleListData, AuditionDetailRoleAdapter.ViewHolder>(DiffCallback()) {
    private var items = mutableListOf<GetAuditionRoleListData>()

    class DiffCallback : DiffUtil.ItemCallback<GetAuditionRoleListData>() {
        override fun areItemsTheSame(
            oldItem: GetAuditionRoleListData,
            newItem: GetAuditionRoleListData
        ): Boolean {
            return oldItem == newItem
        }

        override fun areContentsTheSame(
            oldItem: GetAuditionRoleListData,
            newItem: GetAuditionRoleListData
        ): Boolean {
            return oldItem.roleId == newItem.roleId
        }
    }

    inner class ViewHolder(
        private val binding: ItemAuditionRoleBinding
    ) : RecyclerView.ViewHolder(binding.root) {
        fun bind(item: GetAuditionRoleListData) {
            binding.tvName.text = item.name
            binding.ivCover.load(item.imageUrl) {
                crossfade(true)
                placeholder(R.drawable.bg_placeholder)
                transformations(RoundedCornersTransformation(6.7f.dpToPx()))
            }

            if (item.isComplete) {
                binding.blackCover.visibility = View.VISIBLE
                binding.tvStatus.text = "모집완료"
                binding.tvStatus.setBackgroundResource(R.drawable.bg_round_corner_13_3_909090)
            } else {
                binding.blackCover.visibility = View.GONE
                binding.tvStatus.text = "모집중"
                binding.tvStatus.setBackgroundResource(R.drawable.bg_round_corner_13_3_3bb9f1)
            }

            binding.root.setOnClickListener { onItemClick(item.roleId) }
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int) = ViewHolder(
        ItemAuditionRoleBinding.inflate(
            LayoutInflater.from(parent.context),
            parent,
            false
        )
    )

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        holder.bind(items[position])
    }

    fun addItems(items: List<GetAuditionRoleListData>) {
        this.items.addAll(items)
        submitList(this.items.toList())
    }
}
